@@ -1,5 +1,5 @@
 from datetime import datetime
-from typing import Any, Callable, Dict, Optional
+from typing import Any, Callable, Dict, Optional, Tuple, Type, Union
 from uuid import uuid4
 
 import furl  # type: ignore[import]
@@ -7,7 +7,7 @@ import requests
 from jwcrypto.jwk import JWK  # type: ignore[import]
 from jwcrypto.jwt import JWT  # type: ignore[import]
 
-from requests_oauth2client.utils import b64_encode, b64u_encode, sign_jwt
+from .utils import b64_encode, b64u_encode, sign_jwt
 
 
 class ClientAuthenticationMethod(requests.auth.AuthBase):
@@ -161,18 +161,10 @@ class PrivateKeyJWT(ClientAssertionAuthenticationMethod):
         self.private_jwk = private_jwk
         self.kid = kid
 
-    def client_assertion(
-        self, audience: str, lifetime: int = 60, jti: Optional[str] = None
-    ) -> str:
+    def client_assertion(self, audience: str) -> str:
         iat = int(datetime.now().timestamp())
-        exp = iat + lifetime
-        if jti is None:
-            jti = str(uuid4())
-        elif callable(jti):
-            jti = jti()
-
-        if not isinstance(jti, str):
-            jti = str(jti)
+        exp = iat + self.lifetime
+        jti = str(self.jti_gen())
 
         assertion = sign_jwt(
             claims={
@@ -204,3 +196,33 @@ class PublicApp(ClientAuthenticationMethod):
         data.set([("client_id", self.client_id)])
         request.prepare_body(data.params, files=None)
         return request
+
+
+def client_auth_factory(
+    auth: Union[requests.auth.AuthBase, Tuple[str, str], str],
+    default_auth_handler: Union[
+        Type[ClientSecretPost], Type[ClientSecretBasic]
+    ] = ClientSecretPost,
+) -> requests.auth.AuthBase:
+    if isinstance(auth, requests.auth.AuthBase):
+        return auth
+    elif isinstance(auth, tuple) and len(auth) == 2:
+        client_id, credential = auth
+        if isinstance(credential, dict) and "kty" in credential:
+            private_key = credential
+            return PrivateKeyJWT(str(client_id), private_key)
+        else:
+            return default_auth_handler(str(client_id), credential)
+    elif isinstance(auth, str):
+        client_id = auth
+        return PublicApp(client_id)
+    else:
+        raise ValueError(
+            """Parameter 'auth' is required to define the Authentication Method that this Client will use when sending requests to the Token Endpoint.
+'auth' can be:
+- an instance of a requests.auth.AuthBase subclass, including ClientSecretPost, ClientSecretBasic, ClientSecretJWT, PrivateKeyJWT, PublicApp, 
+- a (client_id, client_secret) tuple, both as str, for ClientSecretPost,
+- a (client_id, private_key) tuple, with client_id as str and private_key as a dict in JWK format, for PrivateKeyJWT,
+- a client_id, as str, for PublicApp.
+"""
+        )
